geowatch.tasks.fusion.datamodules.temporal\_sampling.affinity module
====================================================================

.. automodule:: geowatch.tasks.fusion.datamodules.temporal_sampling.affinity
   :members:
   :undoc-members:
   :show-inheritance:
